import React, { useState, useEffect } from 'react';
import { useParams, Link } from 'react-router-dom';
import axios from 'axios';
import type { JobOffer } from '../types'; // Use type-only import

const API_BASE_URL = 'http://localhost:3000/api/jobs';

const JobDetail: React.FC = () => {
  const { id } = useParams<{ id: string }>();
  const [job, setJob] = useState<JobOffer | null>(null);
  const [loading, setLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const fetchJobDetail = async () => {
      setLoading(true);
      setError(null);
      try {
        const response = await axios.get<JobOffer>(`${API_BASE_URL}/${id}`);
        setJob(response.data);
      } catch (err) {
        console.error('Erreur lors de la récupération des détails de l\'offre:', err);
        if (axios.isAxiosError(err) && err.response?.status === 404) {
          setError('Offre d\'emploi non trouvée.');
        } else {
          setError('Impossible de charger les détails de l\'offre. Veuillez réessayer.');
        }
      } finally {
        setLoading(false);
      }
    };

    if (id) {
      fetchJobDetail();
    }
  }, [id]);

  const handleApplyClick = () => {
    const applyUrl = job?.urlOffre;

    if (applyUrl) {
      window.open(applyUrl, '_blank', 'noopener,noreferrer');
    } else {
      alert("Aucune URL de candidature disponible pour cette offre.");
    }
  };

  if (loading) {
    return <p className="info-message">Chargement des détails de l'offre...</p>;
  }

  if (error) {
    return (
      <div className="job-detail-container">
        <p className="info-message" style={{ color: 'red' }}>Erreur : {error}</p>
        <Link to="/" style={{ display: 'block', textAlign: 'center', marginTop: '20px' }}>Retour à la recherche</Link>
      </div>
    );
  }

      if (!job) {
        return (
          <div className="job-detail-container">
            <p className="info-message">Aucun détail d'offre disponible.</p>
            <Link to="/" style={{ display: 'block', textAlign: 'center', marginTop: '20px' }}>Retour à la recherche</Link>
          </div>
        );
      }

      return (
        <div className="job-detail-container" style={{ padding: '20px', maxWidth: '800px', margin: '20px auto', backgroundColor: '#fff', borderRadius: '8px', boxShadow: '0 4px 8px rgba(0,0,0,0.1)' }}>
          <Link to="/" style={{ textDecoration: 'none', color: '#3498db', fontWeight: 'bold', marginBottom: '20px', display: 'inline-block' }}>
            &larr; Retour à la recherche
          </Link>
          <h1 style={{ color: '#2c3e50', marginBottom: '10px' }}>{job.title}</h1>
          <p style={{ fontSize: '1.1em', color: '#555', marginBottom: '15px' }}>
            <strong>Entreprise :</strong> {job.companyName || 'Non spécifié'}
          </p>
          <p style={{ fontSize: '1.1em', color: '#555', marginBottom: '15px' }}>
            <strong>Localisation :</strong> {job.locationLabel || job.cityName || 'Non spécifié'}
          </p>
          <p style={{ fontSize: '1.1em', color: '#555', marginBottom: '15px' }}>
            <strong>Type de contrat :</strong> {job.contractLabel || job.contractType || 'Non spécifié'}
          </p>
          <p style={{ fontSize: '1.1em', color: '#555', marginBottom: '15px' }}>
            <strong>Date de publication :</strong> {new Date(job.publicationDate).toLocaleDateString('fr-FR')}
          </p>
          {job.romeLabel && <p style={{ fontSize: '1.1em', color: '#555', marginBottom: '15px' }}><strong>Code ROME :</strong> {job.romeLabel}</p>}
          {job.postalCode && <p style={{ fontSize: '1.1em', color: '#555', marginBottom: '15px' }}><strong>Code postal :</strong> {job.postalCode}</p>}
          {job.departmentCode && <p style={{ fontSize: '1.1em', color: '#555', marginBottom: '15px' }}><strong>Département :</strong> {job.departmentCode}</p>}

          <h2 style={{ color: '#2c3e50', marginTop: '30px', marginBottom: '10px' }}>Description</h2>
          <p style={{ lineHeight: '1.6', whiteSpace: 'pre-wrap' }}>{job.description}</p>

          {/* Bouton "Postuler" - s'affiche uniquement si job.urlOffre existe */}
          {job.urlOffre && (
            <button
              onClick={handleApplyClick}
              style={{
                backgroundColor: '#28a745', // Vert pour le bouton "Postuler"
                color: 'white',
                border: 'none',
                borderRadius: '5px',
                padding: '12px 25px',
                fontSize: '1.1em',
                cursor: 'pointer',
                marginTop: '30px',
                display: 'block',
                width: 'fit-content',
                margin: '30px auto 0 auto', // Centre le bouton
                transition: 'background-color 0.3s ease',
              }}
            >
              Postuler maintenant
            </button>
          )}
        </div>
      );
    };

    export default JobDetail;
